@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-permissions-dialog.c,v 1.1 2005/11/05 21:51:07 chpe Exp $
+ *  $Id: ephy-permissions-dialog.c,v 1.3 2005/11/18 18:55:46 chpe Exp $
  */
 
 #include "config.h"
@@ -226,6 +226,10 @@ fill_tab (DialogTab *tab)
 	g_list_foreach (list, (GFunc) ephy_permission_info_free, NULL);
 	g_list_free (list);
 
+	/* Now turn on sorting */
+	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (tab->model),
+					      COL_HOST, GTK_SORT_ASCENDING);
+
 	tab->filled = TRUE;
 }
 
@@ -497,9 +501,6 @@ ephy_permissions_dialog_add_tab (EphyPermissionsDialog *dialog,
 						 G_TYPE_STRING);
 	tab->model = GTK_TREE_MODEL (store);
 
-	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (tab->model),
-					      COL_HOST, GTK_SORT_ASCENDING);
-
 	tab->treeview = treeview = GTK_TREE_VIEW (gtk_tree_view_new_with_model (tab->model));
 	g_object_unref (store);
 
@@ -618,7 +619,10 @@ ephy_permissions_dialog_constructor (GType type,
 
         gtk_window_set_title (GTK_WINDOW (dialog), _("Site Permissions"));
 	gtk_window_set_role (GTK_WINDOW (dialog), "epiphany-permissions-manager");
-	gtk_window_set_icon_name (GTK_WINDOW (dialog), GTK_STOCK_PROPERTIES /* FIXME */);
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), GTK_STOCK_PROPERTIES /* FIXME? */);
+
+	/* Don't stay on top of all windows! */
+	gtk_window_set_type_hint (GTK_WINDOW (dialog), GDK_WINDOW_TYPE_HINT_NORMAL);
 
         gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
         gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
